summaryrefslogtreecommitdiffstats
path: root/kalyptus/kalyptusCxxToSwig.pm
diff options
context:
space:
mode:
Diffstat (limited to 'kalyptus/kalyptusCxxToSwig.pm')
-rw-r--r--kalyptus/kalyptusCxxToSwig.pm82
1 files changed, 41 insertions, 41 deletions
diff --git a/kalyptus/kalyptusCxxToSwig.pm b/kalyptus/kalyptusCxxToSwig.pm
index bd01a125..f25387e7 100644
--- a/kalyptus/kalyptusCxxToSwig.pm
+++ b/kalyptus/kalyptusCxxToSwig.pm
@@ -15,7 +15,7 @@ no strict "subs";
use vars qw/ @clist $host $who $now $gentext %functionId $docTop %typedeflist
$lib $rootnode $outputdir $opt $debug $typeprefix $eventHandlerCount
- $constructorCount *CLASS *HEADER *QTCTYPES *KDETYPES /;
+ $constructorCount *CLASS *HEADER *TQTCTYPES *KDETYPES /;
BEGIN
{
@@ -33,55 +33,55 @@ BEGIN
'unsigned int' => 'uint',
'signed long' => 'long',
'unsigned long' => 'ulong',
- 'QWSEvent*' => 'void*',
- 'QDiskFont*' => 'void*',
+ 'TQWSEvent*' => 'void*',
+ 'TQDiskFont*' => 'void*',
'XEvent*' => 'void*',
- 'QStyleHintReturn*' => 'void*',
+ 'TQStyleHintReturn*' => 'void*',
'FILE*' => 'void*',
- 'QUnknownInterface*' => 'void*',
+ 'TQUnknownInterface*' => 'void*',
'GDHandle' => 'void*',
'_NPStream*' => 'void*',
- 'QTextFormat*' => 'void*',
- 'QTextDocument*' => 'void*',
- 'QTextCursor*' => 'void*',
- 'QTextParag**' => 'void*',
- 'QTextParag* *' => 'void*',
- 'QTextParag*' => 'void*',
- 'QRemoteInterface*' => 'void*',
- 'QSqlRecordPrivate*' => 'void*',
- 'QTSMFI' => 'void*', # QTextStream's QTSManip
+ 'TQTextFormat*' => 'void*',
+ 'TQTextDocument*' => 'void*',
+ 'TQTextCursor*' => 'void*',
+ 'TQTextParag**' => 'void*',
+ 'TQTextParag* *' => 'void*',
+ 'TQTextParag*' => 'void*',
+ 'TQRemoteInterface*' => 'void*',
+ 'TQSqlRecordPrivate*' => 'void*',
+ 'TQTSMFI' => 'void*', # TQTextStream's TQTSManip
'const GUID&' => 'void*',
- 'QWidgetMapper*' => 'void*',
- 'QWidgetMapper *' => 'void*',
+ 'TQWidgetMapper*' => 'void*',
+ 'TQWidgetMapper *' => 'void*',
'MSG*' => 'void*',
- 'const QSqlFieldInfoList&' => 'void*', # QSqlRecordInfo - TODO (templates)
+ 'const TQSqlFieldInfoList&' => 'void*', # TQSqlRecordInfo - TODO (templates)
- 'QPtrCollection::Item' => 'void*', # to avoid a warning
+ 'TQPtrCollection::Item' => 'void*', # to avoid a warning
'mode_t' => 'long',
- 'QProcess::PID' => 'long',
- 'size_type' => 'int', # QSqlRecordInfo
- 'Qt::ComparisonFlags' => 'uint',
- 'Qt::ToolBarDock' => 'int', # compat thing, Qt shouldn't use it
- 'QIODevice::Offset' => 'ulong',
+ 'TQProcess::PID' => 'long',
+ 'size_type' => 'int', # TQSqlRecordInfo
+ 'TQt::ComparisonFlags' => 'uint',
+ 'TQt::ToolBarDock' => 'int', # compat thing, Qt shouldn't use it
+ 'TQIODevice::Offset' => 'ulong',
'WState' => 'int',
'WId' => 'ulong',
- 'QRgb' => 'uint',
- 'QRgb *' => 'uint*',
- 'QRgb*' => 'uint*',
- 'const QCOORD*' => 'const int*',
- 'QCOORD*' => 'int*',
- 'QCOORD' => 'int',
- 'QCOORD &' => 'int&',
- 'QTSMFI' => 'int',
- 'Qt::WState' => 'int',
- 'Qt::WFlags' => 'int',
- 'Qt::HANDLE' => 'uint',
- 'QEventLoop::ProcessEventsFlags' => 'uint',
- 'QStyle::SCFlags' => 'int',
- 'QStyle::SFlags' => 'int',
- 'QStyleOption&' => 'int&',
- 'const QStyleOption&' => 'const int&',
+ 'TQRgb' => 'uint',
+ 'TQRgb *' => 'uint*',
+ 'TQRgb*' => 'uint*',
+ 'const TQCOORD*' => 'const int*',
+ 'TQCOORD*' => 'int*',
+ 'TQCOORD' => 'int',
+ 'TQCOORD &' => 'int&',
+ 'TQTSMFI' => 'int',
+ 'TQt::WState' => 'int',
+ 'TQt::WFlags' => 'int',
+ 'TQt::HANDLE' => 'uint',
+ 'TQEventLoop::ProcessEventsFlags' => 'uint',
+ 'TQStyle::SCFlags' => 'int',
+ 'TQStyle::SFlags' => 'int',
+ 'TQStyleOption&' => 'int&',
+ 'const TQStyleOption&' => 'const int&',
'Q_INT16' => 'short',
'Q_INT32' => 'int',
'Q_INT8' => 'char',
@@ -207,8 +207,8 @@ sub hasPublicConstructors($)
# $child is the method node for which the code should be generated,
# $parentName is the name of the parent for which the code should be generated,
# this is one is tricky, the reason for it is that $child node belongs
# to some class e.g. QWidget and we want to generate a code for $child
# but in a class called QWidget_bridge therefore we need to pass tha name
# $mangleProtected will mangle the name of the method to look like normalNameProtected
# $definition - if set the code generated will be a definition (without the opening
# and closing {} )
@@ -207,8 +207,8 @@ sub hasPublicConstructors($)
# $parentName is the name of the parent for which the code should be generated,
# this is one is tricky, the reason for it is that $child node belongs
-# to some class e.g. QWidget and we want to generate a code for $child
-# but in a class called QWidget_bridge therefore we need to pass tha name
+# to some class e.g. TQWidget and we want to generate a code for $child
+# but in a class called TQWidget_bridge therefore we need to pass tha name
# $mangleProtected will mangle the name of the method to look like normalNameProtected
# $definition - if set the code generated will be a definition (without the opening